# Table of Contents

- [managing-relations-between-fact-sheets](<./managing-relations-between-fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Managing Fact Sheet Relations (GraphQL)](<./Managing-Fact-Sheet-Relations-GraphQL.md>)
  - [Creating Fact Sheet Relations](<./Managing-Fact-Sheet-Relations-GraphQL/Creating-Fact-Sheet-Relations.md>)
  - [Updating Fact Sheet Relations](<./Managing-Fact-Sheet-Relations-GraphQL/Updating-Fact-Sheet-Relations.md>)
  - [Deleting Fact Sheet Relations](<./Managing-Fact-Sheet-Relations-GraphQL/Deleting-Fact-Sheet-Relations.md>)
  - [Setting an Empty Relation on a Fact Sheet](<./Managing-Fact-Sheet-Relations-GraphQL/Setting-an-Empty-Relation-on-a-Fact-Sheet.md>)
  - [Filtering Fact Sheets for Relation Validity](<./Managing-Fact-Sheet-Relations-GraphQL/Filtering-Fact-Sheets-for-Relation-Validity.md>)
  - [Was this page helpful?](<./Managing-Fact-Sheet-Relations-GraphQL/Was-this-page-helpful.md>)
